@@ -32,6 +32,7 @@ from gpt_index.indices.tree import GPTTreeIndex
 from gpt_index.indices.vector_store import (
     GPTFaissIndex,
     GPTPineconeIndex,
+    GPTQdrantIndex,
     GPTSimpleVectorIndex,
     GPTWeaviateIndex,
 )
@@ -62,7 +63,9 @@ from gpt_index.readers import (
     FaissReader,
     GoogleDocsReader,
     NotionPageReader,
+    ObsidianReader,
     PineconeReader,
+    QdrantReader,
     RssReader,
     SimpleDirectoryReader,
     SimpleMongoReader,
@@ -89,6 +92,7 @@ __all__ = [
     "GPTSimpleVectorIndex",
     "GPTWeaviateIndex",
     "GPTPineconeIndex",
+    "GPTQdrantIndex",
     "GPTSQLStructStoreIndex",
     "Prompt",
     "LangchainEmbedding",
@@ -102,6 +106,7 @@ __all__ = [
     "KeywordExtractPrompt",
     "QueryKeywordExtractPrompt",
     "WikipediaReader",
+    "ObsidianReader",
     "Document",
     "SimpleDirectoryReader",
     "SimpleMongoReader",
@@ -112,6 +117,7 @@ __all__ = [
     "WeaviateReader",
     "FaissReader",
     "PineconeReader",
+    "QdrantReader",
     "DiscordReader",
     "SimpleWebPageReader",
     "RssReader",
