@@ -1,8 +1,9 @@
 """Default query for GPTListIndex."""
-from typing import List
+from typing import List, Optional
 
 from gpt_index.data_structs.data_structs import IndexList, Node
 from gpt_index.indices.query.base import BaseGPTIndexQuery
+from gpt_index.indices.query.embedding_utils import SimilarityTracker
 
 
 class BaseGPTListIndexQuery(BaseGPTIndexQuery[IndexList]):
@@ -36,7 +37,10 @@ class GPTListIndexQuery(BaseGPTListIndexQuery):
     """
 
     def _get_nodes_for_response(
-        self, query_str: str, verbose: bool = False
+        self,
+        query_str: str,
+        verbose: bool = False,
+        similarity_tracker: Optional[SimilarityTracker] = None,
     ) -> List[Node]:
         """Get nodes for response."""
         return self.index_struct.nodes
