@@ -4,12 +4,14 @@ An index that that is built on top of an existing vector store.
 
 """
 
-from typing import Any, Optional, Sequence, cast
+from typing import Any, Dict, Optional, Sequence, Type, cast
 
 from gpt_index.data_structs.data_structs import WeaviateIndexStruct
 from gpt_index.embeddings.base import BaseEmbedding
 from gpt_index.indices.base import DOCUMENTS_INPUT, BaseGPTIndex
+from gpt_index.indices.query.base import BaseGPTIndexQuery
 from gpt_index.indices.query.schema import QueryMode
+from gpt_index.indices.query.vector_store.weaviate import GPTWeaviateIndexQuery
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
 from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
 from gpt_index.prompts.default_prompts import DEFAULT_TEXT_QA_PROMPT
@@ -88,6 +90,14 @@ class GPTWeaviateIndex(BaseGPTIndex[WeaviateIndexStruct]):
             self.text_qa_template, 1
         )
 
+    @classmethod
+    def get_query_map(self) -> Dict[str, Type[BaseGPTIndexQuery]]:
+        """Get query map."""
+        return {
+            QueryMode.DEFAULT: GPTWeaviateIndexQuery,
+            QueryMode.EMBEDDING: GPTWeaviateIndexQuery,
+        }
+
     def _add_document_to_index(
         self,
         index_struct: WeaviateIndexStruct,
